import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { ChatEmbed } from "../models/ChatEmbed";
import type { ChatMessage } from "../models/ChatMessage";
import type { Mentions } from "../models/Mentions";
export declare class ChatService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a channel message
     * @returns any Success
     * @throws ApiError
     */
    channelMessageCreate({ channelId, requestBody, }: {
        /**
         * Channel ID to create the message in
         */
        channelId: string;
        requestBody: {
            /**
             * If set, this message will only be seen by those mentioned or replied to
             */
            isPrivate?: boolean;
            /**
             * If set, this message will not notify any mentioned users or roles
             */
            isSilent?: boolean;
            /**
             * Message IDs to reply to
             */
            replyMessageIds?: Array<string>;
            /**
             * The content of the message
             */
            content?: string;
            /**
             * Links in `content` to prevent unfurling as a link preview when displaying in Guilded
             */
            hiddenLinkPreviewUrls?: Array<string>;
            /**
             * At this time, only one embed is supported per message, and attachments are not supported. If you need to send more than one embed or upload attachments, consider creating the message via a webhook.
             */
            embeds?: Array<ChatEmbed>;
        };
    }): CancelablePromise<{
        message: ChatMessage;
    }>;
    /**
     * Get channel messages
     * Results returned will be ordered ascending by the message's `createdAt`. `before` and `after` will filter based on the message's `createdAt`
     * @returns any Success
     * @throws ApiError
     */
    channelMessageReadMany({ channelId, before, after, limit, includePrivate, }: {
        /**
         * ID of the channel that the messages exist in
         */
        channelId: string;
        before?: string;
        /**
         * An ISO 8601 timestamp that will be used to filter out results for the current page. Order will be reversed when compared to `before` or when omitting this parameter altogether
         */
        after?: string;
        limit?: number;
        /**
         * Whether to include private messages between all users in response
         */
        includePrivate?: boolean;
    }): CancelablePromise<{
        messages: Array<ChatMessage>;
    }>;
    /**
     * Get a channel message
     * Get details for a specific chat message from a chat channel.
     * @returns any Success
     * @throws ApiError
     */
    channelMessageRead({ channelId, messageId, }: {
        /**
         * ID of the channel that the message exists in
         */
        channelId: string;
        messageId: string;
    }): CancelablePromise<{
        message: ChatMessage;
    }>;
    /**
     * Update a channel message
     * @returns any Success
     * @throws ApiError
     */
    channelMessageUpdate({ channelId, messageId, requestBody, }: {
        /**
         * ID of the channel that the message to be updated exists in
         */
        channelId: string;
        messageId: string;
        requestBody: {
            /**
             * The content of the message
             */
            content?: Record<string, any> | string;
            /**
             * Links in `content` to prevent unfurling as a link preview when displaying in Guilded
             */
            hiddenLinkPreviewUrls?: Array<string>;
            /**
             * At this time, only one embed is supported per message, and attachments are not supported. If you need to send more than one embed or upload attachments, consider creating the message via a webhook.
             */
            embeds?: Array<ChatEmbed>;
        };
    }): CancelablePromise<{
        message: ChatMessage & {
            /**
             * The ID of the message
             */
            id?: string;
            /**
             * The type of chat message. "system" messages are generated by Guilded, while "default" messages are user or bot-generated.
             */
            type?: "default" | "system";
            /**
             * The ID of the server
             */
            serverId?: string;
            /**
             * The ID of the group
             */
            groupId?: string;
            /**
             * The ID of the channel
             */
            channelId?: string;
            /**
             * The content of the message
             */
            content?: string;
            /**
             * Links in `content` to prevent unfurling as a link preview when displaying in Guilded
             */
            hiddenLinkPreviewUrls?: Array<string>;
            embeds?: Array<ChatEmbed>;
            /**
             * Message IDs that were replied to
             */
            replyMessageIds?: Array<string>;
            /**
             * If set, this message will only be seen by those mentioned or replied to
             */
            isPrivate?: boolean;
            /**
             * If set, this message did not notify mention or reply recipients
             */
            isSilent?: boolean;
            isPinned?: boolean;
            mentions?: Mentions;
            /**
             * The ISO 8601 timestamp that the message was created at
             */
            createdAt?: string;
            /**
             * The ID of the user who created this message (Note: If this event has `createdByWebhookId` present, this field will still be populated, but can be ignored. In this case, the value of this field will always be Ann6LewA)
             */
            createdBy?: string;
            /**
             * The ID of the webhook who created this message, if it was created by a webhook
             */
            createdByWebhookId?: string;
            /**
             * The ISO 8601 timestamp that the message was updated at, if relevant
             */
            updatedAt: string;
        };
    }>;
    /**
     * Delete a channel message
     * @returns void
     * @throws ApiError
     */
    channelMessageDelete({ channelId, messageId, }: {
        channelId: string;
        messageId: string;
    }): CancelablePromise<void>;
    /**
     * Pin a message
     * @returns void
     * @throws ApiError
     */
    channelMessagePinCreate({ channelId, messageId, }: {
        channelId: string;
        messageId: string;
    }): CancelablePromise<void>;
    /**
     * Unpin a message
     * @returns void
     * @throws ApiError
     */
    channelMessagePinDelete({ channelId, messageId, }: {
        channelId: string;
        messageId: string;
    }): CancelablePromise<void>;
}
//# sourceMappingURL=ChatService.d.ts.map